# frozen_string_literal: true

lib = File.expand_path('lib', __dir__)
$LOAD_PATH.unshift(lib) unless $LOAD_PATH.include?(lib)
require 'localizationlinter/gem_version'

Gem::Specification.new do |spec|
  spec.name          = 'danger-localizationlinter'
  spec.version       = Localizationlinter::VERSION
  spec.authors       = ['Fabernovel']
  spec.email         = ['benjamin.lavialle@fabernovel.com', 'claire.peyron@fabernovel.com']
  spec.description   = 'This is a danger plugin checking the consistency of localizable folders in a xcode project'
  spec.summary       = 'Verify consistency over your project localizable files (localizable.strings and Localizable.stringdict).
It uses Swiftgen to generate a localizables output per target and language and compare the output with a reference language one.
The comparison ensure:
  - missing keys
  - additional keys
  - wrong parameters in string format
'
  spec.homepage      = 'https://github.com/fabernovel/danger-localizationlinter'
  spec.license       = 'MIT'

  spec.files         = `git ls-files`.split($INPUT_RECORD_SEPARATOR)
  spec.executables   = spec.files.grep(%r{^bin/}) { |f| File.basename(f) }
  spec.test_files    = spec.files.grep(%r{^(test|spec|features)/})
  spec.require_paths = ['lib']

  spec.add_runtime_dependency 'danger-plugin-api', '~> 1.0'

  spec.add_dependency 'yaml', '~> 0.1'
  spec.add_dependency 'json-diff', '~> 0.4'
  spec.add_dependency 'xcodeproj', '~> 1.19'

  # General ruby development
  spec.add_development_dependency 'bundler', '~> 2.0'
  spec.add_development_dependency 'rake', '~> 10.0'

  # Testing support
  spec.add_development_dependency 'rspec', '~> 3.4'

  # Linting code and docs
  spec.add_development_dependency 'rubocop'
  spec.add_development_dependency 'yard'

  # Makes testing easy via `bundle exec guard`
  spec.add_development_dependency 'guard', '~> 2.14'
  spec.add_development_dependency 'guard-rspec', '~> 4.7'

  # If you want to work on older builds of ruby
  spec.add_development_dependency 'listen', '3.0.7'

  # This gives you the chance to run a REPL inside your tests
  # via:
  #
  #    require 'pry'
  #    binding.pry
  #
  # This will stop test execution and let you inspect the results
  spec.add_development_dependency 'pry'
end
